import React, { useEffect } from 'react';
import { useTagsAndCommitIds, useCSentryHost } from "../../api/SwaggerApi";
import { JobTable } from './JobTable';

export function JobAsyncList({ jobs, setJobs, rowType, totalCount, lazyParams, setLazyParams, columnSort, setColumnSort, rowsPerPage, loading, paginator }) {
  console.log(jobs);
  const jobDetailFetchers =
    jobs.map((job, index) => <JobDetailFetcher
      key={`${job.type}-fetcher-${job.id}`} deployment={job} index={index} setDeployments={setJobs} />);
  console.log("JobListView DeploymentsAsyncList deployments", jobs)
  return (
    <>
      <JobTable
        jobs={jobs} rowType={rowType} loading={loading}
        totalCount={totalCount} lazyParams={lazyParams} setLazyParams={setLazyParams} columnSort={columnSort} setColumnSort={setColumnSort}
        rowsPerPage={rowsPerPage}
      />
      {jobDetailFetchers}
    </>
  );
}

function onError(message) {
  console.warn(message);
}

export function JobDetailFetcher({ deployment, index, setDeployments }) {
  const [tagOrCommitId, getTagOrCommitId] = useTagsAndCommitIds(onError);
  const [host, getHost] = useCSentryHost(onError);

  useEffect(() => {
    getTagOrCommitId(deployment.gitProjectId, deployment.sourceVersion);
    getHost(deployment.host.externalHostId);
  }, [deployment, getTagOrCommitId, getHost])

  useEffect(() => {
    setDeployments((deployments) => {
      deployments[index].sourceVersionShort = tagOrCommitId?.length === 1 ? tagOrCommitId[0].shortReference : deployments[index].gitReference;
      deployments[index].host = host ?? deployments[index].host;
      return [...deployments];
    });
  }, [index, setDeployments, tagOrCommitId, host])

  return null;
}